==> graph-0.2.0.tgz: package/src/components/graph.jsx <==
import React, { useRef } from 'react'
import PropTypes from 'prop-types'
import Clear from './clear.jsx'
import { GraphContext } from '../utils/index.js'
import { zoomIdentity } from 'd3-zoom'
import * as d3 from 'd3-force'


const Graph = ({
    width = 500,
    height = 500,
    nodes = [],
    links = [],
    children,
    forces = {
        collision: d3.forceCollide().radius(30).strength(0.25),
        charge: d3.forceManyBody().strength(-400).theta(0.1),
        x: d3.forceX(),
        y: d3.forceY()
    }
}) => {
    const canvas = useRef(null)
    const simulation = d3.forceSimulation(nodes)

    simulation.force('link', d3.forceLink(links))
    simulation.force('center', d3.forceCenter(width / 2, height / 2))
    simulation.transform = zoomIdentity

    Object.keys(forces).forEach(key => {
        simulation.force(key, forces[key])
    })

    return (
        <GraphContext.Provider value={{
            canvas,
            simulation,
            links,
            nodes,
            transform: null
        }}>
            <canvas
                ref={canvas}
                width={width}
                height={height}
            >
                <Clear width={width} height={height} />
                {children}
            </canvas>
        </GraphContext.Provider>
    )
}

Graph.propTypes = {
    width: PropTypes.number,
    height: PropTypes.number,
    node: PropTypes.array,
    links: PropTypes.array,
    children: PropTypes.node,
    forces: PropTypes.object
}

export default Graph

==> graph-0.2.2.tgz: package/src/components/graph.jsx <==
import React, { useRef } from 'react'
import PropTypes from 'prop-types'
import Clear from './clear.jsx'
import { GraphContext } from '../utils/index.js'
import { zoomIdentity } from 'd3-zoom'
import * as d3 from 'd3-force'


const Graph = ({
    width = 500,
    height = 500,
    nodes = [],
    links = [],
    children,
    forces = {
        collision: d3.forceCollide().radius(30).strength(0.25),
        charge: d3.forceManyBody().strength(-90),
        x: d3.forceX().strength(0.01),
        y: d3.forceY().strength(0.01)
    }
}) => {
    const canvas = useRef(null)
    const simulation = d3.forceSimulation(nodes)

    simulation.force('link', d3.forceLink(links).id(d => d.id || d.index))
    simulation.force('center', d3.forceCenter(width / 2, height / 2))
    simulation.transform = zoomIdentity

    Object.keys(forces).forEach(key => {
        simulation.force(key, forces[key])
    })

    return (
        <GraphContext.Provider value={{
            canvas,
            simulation,
            links,
            nodes,
            transform: null,
            bounds: {
                width,
                height
            }
        }}>
            <canvas
                ref={canvas}
                width={width}
                height={height}
            >
                <Clear width={width} height={height} />
                {children}
            </canvas>
        </GraphContext.Provider>
    )
}

Graph.propTypes = {
    width: PropTypes.number,
    height: PropTypes.number,
    node: PropTypes.array,
    links: PropTypes.array,
    children: PropTypes.node,
    forces: PropTypes.object
}

export default Graph
